==> GCharts-1.3.1.tar.gz: GCharts/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'GCharts';
$lang['postinstall'] = 'Be sure to set "Use GCharts" permissions to use this module!';
$lang['postuninstall'] = 'Sorry, it\'s not you, it\'s me.';
$lang['really_uninstall'] = 'Really? You\'re sure you want to uninstall this super fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['prefsupdated'] = 'Module preferences updated.';
$lang['edit'] = 'Edit';
$lang['delete'] = 'Delete';
$lang['approve'] = 'Set Status to \'Enabled\'';
$lang['revert'] = 'Set Status to \'Disabled\'';
$lang['submit'] = 'Save';
$lang['cancel'] = 'Cancel';
$lang['addchart'] = 'Add chart';
$lang['charts'] = 'Charts';
$lang['chart'] = 'Chart';
$lang['data'] = 'Data';
$lang['published'] = 'Published';
$lang['draft'] = 'Draft';
$lang['status'] = 'Status';
$lang['select'] = 'Select';
$lang['reassign_category'] = 'Re-assign category';
$lang['delete_selected'] = 'Delete selected';
$lang['nonamegiven'] = 'No name given';
$lang['nodatagiven'] = 'No data given';
$lang['areyousure_deletemultiple'] = 'Are you sure you want to delete the selected charts?';
$lang['chartadded'] = 'Chart added';
$lang['chartupdated'] = 'Chart updated';
$lang['id'] = 'Chart ID';
$lang['name'] = 'Chart Title';
$lang['element'] = 'Containing element ID';
$lang['enableInteractivity'] = 'Enable interactivity';
$lang['category'] = 'Chart category';
$lang['gcharts_data'] = 'Chart Data';
$lang['axisTitlesPosition'] = 'Axis titles position';
$lang['backgroundColor'] = 'Background Color';
$lang['curveType'] = 'Curve type';
$lang['chartArea'] = 'Chart Area';
$lang['colors'] = 'Colors';
$lang['focusTarget'] = 'Font target';
$lang['fontSize'] = 'Font Size';
$lang['fontName'] = 'Font Name';
$lang['hAxes'] = 'hAxes';
$lang['hAxis'] = 'hAxis';
$lang['height'] = 'Height';
$lang['interpolatedNulls'] = 'Interpolated nulls';
$lang['isStacked'] = 'Is stacked';
$lang['isHtml'] = 'Is HTML';
$lang['is3D'] = 'Is 3D';
$lang['legend'] = 'Legend';
$lang['lineWidth'] = 'Line width';
$lang['slices'] = 'Slices';
$lang['pieSliceBorderColor'] = 'Pie Slice Boarder Color';
$lang['pieSliceText'] = 'Pie Slice Text';
$lang['pieSliceTextStyle'] = 'Pie Slice Text Style';
$lang['pointSize'] = 'Point size';
$lang['reverseCategories'] = 'Reverse Categories';
$lang['sliceVisibilityThreshold'] = 'Slice Visibility Threshold';
$lang['pieResidueSliceColor'] = 'Pie Residue Slice Color';
$lang['pieResidueSliceLabel'] = 'Pie Residue Slice Label';
$lang['titlePosition'] = 'Title position';
$lang['title'] = 'Title';
$lang['theme'] = 'Theme';
$lang['series'] = 'Series';
$lang['titleTextStyle'] = 'Title Text Style';
$lang['tooltip'] = 'Tooltip';
$lang['vAxes'] = 'vAxes';
$lang['vAxis'] = 'vAxis';
$lang['width'] = 'Width';
$lang['aggregationTarget'] = 'Aggregation Target';
$lang['groupWidth'] = 'Group Width';
$lang['dataOpacity'] = 'Data Opacity';
$lang['avoidOverlappingGridLines'] = 'Avoid Overlapping Grid Lines';
$lang['timeline'] = 'Timeline';
$lang['error_nochartsselected'] = 'No Charts Were Selected';

$lang['areyousure'] = 'Are you sure you want to delete?';
$lang['dash_record_count'] = 'This module handles %s documents';
$lang['alert_no_records'] = 'There have not been any documents added in the GCharts module!';
$lang['help_gcharts_id'] = 'Internally identifier for selecting documents';
$lang['help_description'] = 'Internal parameter used to pass description info when creating or editing a document';
$lang['help_explanation'] = 'Internal parameter used to pass explanation info when creating or editing a document';
$lang['help_module_message'] = 'Internally used parameter for passing messages to user';
$lang['help_gcharts_id'] = 'ID of the chart you want to display.';

$lang['moddescription'] = 'This module add Google Charts to your website.';
$lang['changelog'] = '<ul>
<li>Version 1.0 8 July 2013. Initial Release.</li>
<li>Version 1.1 15 July 2013. Multiple bug fixes.</li>
<li>Version 1.2 14 November 2013. Added column charts option plus many bug fixes.</li>
<li>Version 1.3 5 December 2013. Added Histogram and Timeline chart options plus minor bug fixes and code tidying up.</li>
<li>Version 1.3.1 11 December 2013. Added the ability for GCharts to create chart div element automatically if no containing element ID is specified and bug fixes.</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module allows for the addition of Google Charts to your website.</p>
<h3>How Do I Use It</h3>
<p>Simply place the module call before your closing body tag with the ID of the chart you want to display <code>{GCharts gcharts_id=\'1\'}</code>, data field accepts smarty variables.</p>
<p>For detailed information as to what values each parameter takes look at the Google Charts documentation <a href="https://google-developers.appspot.com/chart/">https://google-developers.appspot.com/chart/</a></p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the Module Forge
<a href="http://dev.cmsmadesimple.org/projects/gcharts/">GCharts Page</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, oliverseddon, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2013, Oliver Seddon <a href="mailto:oliver@threefold.co.uk">&lt;oliver@threefold.co.uk&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
?>

==> GCharts-1.4.1.tar.gz: GCharts/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'GCharts';
$lang['postinstall'] = 'Be sure to set "Use GCharts" permissions to use this module!';
$lang['postuninstall'] = 'Sorry, it\'s not you, it\'s me.';
$lang['really_uninstall'] = 'Really? You\'re sure you want to uninstall this super fine module?';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['installed'] = 'Module version %s installed.';
$lang['prefsupdated'] = 'Module preferences updated.';
$lang['edit'] = 'Edit';
$lang['delete'] = 'Delete';
$lang['approve'] = 'Set Status to \'Enabled\'';
$lang['revert'] = 'Set Status to \'Disabled\'';
$lang['submit'] = 'Save';
$lang['cancel'] = 'Cancel';
$lang['addchart'] = 'Add chart';
$lang['charts'] = 'Charts';
$lang['chart'] = 'Chart';
$lang['data'] = 'Data';
$lang['published'] = 'Published';
$lang['draft'] = 'Draft';
$lang['status'] = 'Status';
$lang['select'] = 'Select';
$lang['reassign_category'] = 'Re-assign category';
$lang['delete_selected'] = 'Delete selected';
$lang['nonamegiven'] = 'No name given';
$lang['nodatagiven'] = 'No data given';
$lang['areyousure_deletemultiple'] = 'Are you sure you want to delete the selected charts?';
$lang['chartadded'] = 'Chart added';
$lang['chartupdated'] = 'Chart updated';
$lang['id'] = 'Chart ID';
$lang['name'] = 'Chart Title';
$lang['element'] = 'Containing element ID';
$lang['enableInteractivity'] = 'Enable interactivity';
$lang['category'] = 'Chart category';
$lang['gcharts_data'] = 'Chart Data';
$lang['axisTitlesPosition'] = 'Axis titles position';
$lang['backgroundColor'] = 'Background Color';
$lang['curveType'] = 'Curve type';
$lang['chartArea'] = 'Chart Area';
$lang['colors'] = 'Colors';
$lang['focusTarget'] = 'Font target';
$lang['fontSize'] = 'Font Size';
$lang['fontName'] = 'Font Name';
$lang['hAxes'] = 'hAxes';
$lang['hAxis'] = 'hAxis';
$lang['height'] = 'Height';
$lang['interpolatedNulls'] = 'Interpolated nulls';
$lang['isStacked'] = 'Is stacked';
$lang['isHtml'] = 'Is HTML';
$lang['is3D'] = 'Is 3D';
$lang['legend'] = 'Legend';
$lang['lineWidth'] = 'Line width';
$lang['slices'] = 'Slices';
$lang['pieSliceBorderColor'] = 'Pie Slice Boarder Color';
$lang['pieSliceText'] = 'Pie Slice Text';
$lang['pieSliceTextStyle'] = 'Pie Slice Text Style';
$lang['pointSize'] = 'Point size';
$lang['reverseCategories'] = 'Reverse Categories';
$lang['sliceVisibilityThreshold'] = 'Slice Visibility Threshold';
$lang['pieResidueSliceColor'] = 'Pie Residue Slice Color';
$lang['pieResidueSliceLabel'] = 'Pie Residue Slice Label';
$lang['titlePosition'] = 'Title position';
$lang['title'] = 'Title';
$lang['theme'] = 'Theme';
$lang['series'] = 'Series';
$lang['titleTextStyle'] = 'Title Text Style';
$lang['tooltip'] = 'Tooltip';
$lang['vAxes'] = 'vAxes';
$lang['vAxis'] = 'vAxis';
$lang['width'] = 'Width';
$lang['aggregationTarget'] = 'Aggregation Target';
$lang['groupWidth'] = 'Group Width';
$lang['dataOpacity'] = 'Data Opacity';
$lang['avoidOverlappingGridLines'] = 'Avoid Overlapping Grid Lines';
$lang['timeline'] = 'Timeline';
$lang['allowHtml'] = 'Allow HTML';
$lang['alternatingRowStyle'] = 'Alternating Row Style';
$lang['cssClassNames'] = 'CSS Class Names';
$lang['firstRowNumber'] = 'First Row Number';
$lang['chartpage'] = 'Page';
$lang['pageSize'] = 'Page Size';
$lang['rtlTable'] = 'RTL Table';
$lang['scrollLeftStartPosition'] = 'Scroll Left Start Position';
$lang['showRowNumber'] = 'Show Row Number';
$lang['sort'] = 'Sort';
$lang['sortAscending'] = 'Sort Ascending';
$lang['sortColumn'] = 'Sort Column';
$lang['startPage'] = 'Start Page';
$lang['error_nochartsselected'] = 'No Charts Were Selected';
$lang['prompt_of'] = 'of';

$lang['areyousure'] = 'Are you sure you want to delete?';
$lang['dash_record_count'] = 'This module handles %s documents';
$lang['alert_no_records'] = 'There have not been any documents added in the GCharts module!';
$lang['help_description'] = 'Internal parameter used to pass description info when creating or editing a document';
$lang['help_explanation'] = 'Internal parameter used to pass explanation info when creating or editing a document';
$lang['help_module_message'] = 'Internally used parameter for passing messages to user';
$lang['help_gcharts_id'] = 'ID of the chart you want to display.';
$lang['help_gcharts_category_id'] = 'ID of the category you want to use. 1 = Pie, 2 = Line, 3 = Bar, 4 = Column, 5 = Histogram, 6 = Timeline and 7 = Table';
$lang['help_backgroundColor'] = '';
$lang['help_chartArea'] = '';
$lang['help_colors'] = '';
$lang['help_fontSize'] = '';
$lang['help_fontName'] = '';
$lang['help_height'] = '';
$lang['help_legend'] = '';
$lang['help_reverseCategories'] = '';
$lang['help_titleTextStyle'] = '';
$lang['help_tooltip'] = '';
$lang['help_width'] = '';
$lang['help_is3D'] = '';
$lang['help_slices'] = '';
$lang['help_pieSliceBorderColor'] = '';
$lang['help_pieSliceText'] = '';
$lang['help_pieSliceTextStyle'] = '';
$lang['help_sliceVisibilityThreshold'] = '';
$lang['help_pieResidueSliceColor'] = '';
$lang['help_pieResidueSliceLabel'] = '';
$lang['help_axisTitlesPosition'] = '';
$lang['help_enableInteractivity'] = '';
$lang['help_focusTarget'] = '';
$lang['help_hAxis'] = '';
$lang['help_isHtml'] = '';
$lang['help_series'] = '';
$lang['help_theme'] = '';
$lang['help_titlePosition'] = '';
$lang['help_vAxes'] = '';
$lang['help_aggregationTarget'] = '';
$lang['help_curveType'] = '';
$lang['help_interpolatedNulls'] = '';
$lang['help_vAxis'] = '';
$lang['help_lineWidth'] = '';
$lang['help_pointSize'] = '';
$lang['help_isStacked'] = '';
$lang['help_groupWidth'] = '';
$lang['help_dataOpacity'] = '';
$lang['help_avoidOverlappingGridLines'] = '';
$lang['help_timeline'] = '';
$lang['help_allowHtml'] = '';
$lang['help_alternatingRowStyle'] = '';
$lang['help_cssClassNames'] = '';
$lang['help_firstRowNumber'] = '';
$lang['help_chartpage'] = '';
$lang['help_pageSize'] = '';
$lang['help_rtlTable'] = '';
$lang['help_scrollLeftStartPosition'] = '';
$lang['help_showRowNumber'] = '';
$lang['help_sort'] = '';
$lang['help_sortAscending'] = '';
$lang['help_sortColumn'] = '';
$lang['help_startPage'] = '';

$lang['moddescription'] = 'This module add Google Charts to your website.';
$lang['changelog'] = '<ul>
<li>Version 1.0 8 July 2013. Initial Release.</li>
<li>Version 1.1 15 July 2013. Multiple bug fixes.</li>
<li>Version 1.2 14 November 2013. Added column charts option plus many bug fixes.</li>
<li>Version 1.3 5 December 2013. Added Histogram and Timeline chart options plus minor bug fixes and code tidying up.</li>
<li>Version 1.3.1 11 December 2013. Added the ability for GCharts to create chart div element automatically if no containing element ID is specified and bug fixes.</li>
<li>Version 1.4 3 February 2014. Added category id paramter to enable data to be displayed in multiple formats with only one entry, plus minor bug fixes and new Table category.</li>
<li>Version 1.4.1 29 April 2014. Fixed bug where only Admin user could edit charts.</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This module allows for the addition of Google Charts to your website.</p>
<h3>How Do I Use It</h3>
<p>Simply place the module call before your closing body tag with the ID of the chart you want to display <code>{GCharts gcharts_id=\'1\'}</code>, data field accepts smarty variables.</p>
<p>
<p>For detailed information as to what values each parameter takes look at the Google Charts documentation <a href="https://google-developers.appspot.com/chart/">https://google-developers.appspot.com/chart/</a></p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the Module Forge
<a href="http://dev.cmsmadesimple.org/projects/gcharts/">GCharts Page</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, oliverseddon, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>  
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2014, Oliver Seddon <a href="mailto:oliver@threefold.co.uk">&lt;oliver@threefold.co.uk&gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
?>
